@@ -152,15 +152,11 @@ pub fn solve(
         (2017, 24, _) => to_stringer_input(year2017::day24::solve, &mut input),
         (2017, 25, _) => to_stringer_input(year2017::day25::solve, &mut input),
         (2018, 1, _) => to_stringer_input(year2018::day01::solve, &mut input),
-        (2018, 2, 1) => to_stringer(year2018::day02::part1, input_string),
-        (2018, 2, 2) => to_stringer(year2018::day02::part2, input_string),
+        (2018, 2, _) => to_stringer_input(year2018::day02::solve, &mut input),
         (2018, 3, _) => to_stringer_input(year2018::day03::solve, &mut input),
-        (2018, 4, 1) => to_stringer(year2018::day04::part1, input_string),
-        (2018, 4, 2) => to_stringer(year2018::day04::part2, input_string),
-        (2018, 5, 1) => to_stringer(year2018::day05::part1, input_string),
-        (2018, 5, 2) => to_stringer(year2018::day05::part2, input_string),
-        (2018, 6, 1) => to_stringer(year2018::day06::part1, input_string),
-        (2018, 6, 2) => to_stringer(year2018::day06::part2, input_string),
+        (2018, 4, _) => to_stringer_input(year2018::day04::solve, &mut input),
+        (2018, 5, _) => to_stringer_input(year2018::day05::solve, &mut input),
+        (2018, 6, _) => to_stringer_input(year2018::day06::solve, &mut input),
         (2018, 7, 1) => to_stringer(year2018::day07::part1, input_string),
         (2018, 7, 2) => to_stringer(year2018::day07::part2, input_string),
         (2018, 8, 1) => to_stringer(year2018::day08::part1, input_string),
